# The upstream projects uses 4 digits after the version number to indicate
# minor changes after the release:
%global upstream_version 3.0.0
%global upstream_release 0001

# Short names for directories:
%global engine_data_dir %{_datadir}/%{name}
%global engine_jar_dir %{_javadir}/%{name}
%global engine_bin_dir %{engine_data_dir}/bin
%global engine_modules_dir %{engine_data_dir}/modules
%global engine_deployments_dir %{engine_data_dir}/deployments
%global engine_content_dir %{_var}/lib/ovirt-engine
%global engine_temp_dir %{_var}/cache/ovirt-engine
%global engine_ear_dir %{engine_deployments_dir}/engine.ear
%global engine_pki_dir %{_sysconfdir}/pki/%{name}
%global restapi_war_dir %{engine_ear_dir}/restapi.war
%global root_war_dir %{engine_deployments_dir}/ROOT.war

# The name of the engine user and group:
%global engine_group ovirt
%global engine_user ovirt
%global engine_uid 108

# Directory to install python libraries:
%global py_site_pkgs %(python -c "from distutils.sysconfig import get_python_lib as f;print f()")

# Macro to create the engine user:
%global create_engine_user \
/bin/getent group %{engine_group} >/dev/null || /sbin/groupadd -r %{engine_group}; \
/bin/getent passwd %{engine_user} >/dev/null || /sbin/useradd -c "oVirt Manager" -u %{engine_uid} -g %{engine_group} -s /bin/nologin %{engine_user}

Name: ovirt-engine
Version: %{upstream_version}.%{upstream_release}
Release: 12%{?dist}
Summary: Management server for Open Virtualization
Group: Applications/System
License: ASL 2.0
URL: http://www.ovirt.org

# Upstream source code:
Source0: http://ovirt.org/releases/stable/src/%{name}-%{upstream_version}_%{upstream_release}.tar.gz

BuildArch: noarch

# Build only the backend:
Patch0: %{name}-build-backend-only.patch

# Remove some dependencies used only for tests:
Patch1: %{name}-remove-mockito.patch
Patch10: %{name}-remove-powermock.patch
Patch20: %{name}-remove-p6spy.patch

# Remove JB5 specifc login module:
# Upstream: http://gerrit.ovirt.org/2353
Patch30: %{name}-remove-jb5-login-module.patch

# Add log4j:
# Upstream: http://gerrit.ovirt.org/2353
Patch40: %{name}-add-log4j.patch

# Add the dummy Hibernate annotations:
Patch50: %{name}-add-dummy-hibernate-annotations.patch
Patch60: %{name}-use-hibernate-jpa-2.0-api.patch
Patch70: %{name}-replace-guidtype-with-empty-class.patch

# Remove the dependency on JNA, as this was useful in Windows only:
# Upstream: http://gerrit.ovirt.org/3249 
Patch80: %{name}-remove-jna.patch

# Remove the dependency on jboss interceptors as it is not used and complicates
# building:
# Upstream: http://gerrit.ovirt.org/1997
Patch100: %{name}-remove-jboss-interceptors.patch

# Remove all the Hibernate DAOs as they are not used currently and the bring a
# lot of dependencies:
Patch110: %{name}-remove-hibernate-daos.patch

# Add the methods missing in PGHack:
# Upstream: http://gerrit.ovirt.org/2347
Patch120: %{name}-add-pghack-missing-methods.patch

# Remove dependency on JBoss EJB specific annotations as they are not used and
# they complicate the building in Fedora:
# Upstream: http://gerrit.ovirt.org/2008
# Upstream: http://gerrit.ovirt.org/2015
Patch130: %{name}-remove-jboss-ejb-specific-annotations.patch

# Update to Quartz 2.1:
# Upstream: http://gerrit.ovirt.org/3250
Patch140: %{name}-update-to-quartz-2.1.patch

# Remove local user authentication as this only makes sense in Windows:
# Upstream:  http://gerrit.ovirt.org/3249
Patch150: %{name}-remove-local-user-authentication.patch

# Don't use the hibernate string helper, just to avoid the dependency in
# hibernate:
# Upstream: http://gerrit.ovirt.org/3252
Patch160: %{name}-dont-use-hibernate-string-helper.patch

# Use the version of the XJC compiler and the corresponding Maven plugin that
# are available in Fedora:
# Upstream: http://gerrit.ovirt.org/2222
Patch170: %{name}-use-maven-jaxb2-plugin.patch

# Update the custom serializer to use the builder class used starting with
# Jackson 1.7:
# Upstream: http://gerrit.ovirt.org/3251
Patch180: %{name}-update-to-jackson-1.9.patch

# Remove Spring from the RESTAPI:
# Upstream: http://gerrit.ovirt.org/1390
Patch190: %{name}-remove-spring-from-restapi.patch

# Don't require activation, as it is included in Java 7 and there is no package
# for it:
# Upstream: http://gerrit.ovirt.org/2354
Patch200: %{name}-dont-use-activation.patch

# Newer versions of the assembly plugin complain if there is no id in the
# assembly.xml file:
Patch210: %{name}-add-id-to-the-notifier-assembly.patch

# Fix a generics related bug in the Postgres dialect class:
Patch220: %{name}-fix-postgresdbenginedialect.patch

# The spring-agent artifact has been renamed to spring-instrument starting with
# Spring 3:
Patch240: %{name}-use-spring-instrument-instead-of-spring-agent.patch

# Remove the frontend related content from the ear:
Patch250: %{name}-remove-frontend-from-ear.patch

# Replace pubkey2ssh with ssh-keygen in order to make the package noarch:
# Upstream: http://gerrit.ovirt.org/3086
Patch260: %{name}-replace-pubkey2ssh-with-ssh-keygen.patch

# Use build-classpath in scripts:
Patch270: %{name}-fix-classpath-building-in-scripts.patch

# Create the CA database files when needed instead of including them in the
# package:
Patch310: %{name}-create-database-and-serial-when-needed.patch

# Add the modules required by the engine and those included with the
# application server but that need to be overriden:
Patch340: %{name}-add-modules.patch

# Add the resteasy listener to the restapi, as the current version of the
# application server doesn't include the bootstrap of resteasy:
Patch350: %{name}-add-resteasy-listener-to-restapi.patch

# Fixes for the makefile and for the setup tool:
Patch360: %{name}-makefile-fixes.patch
Patch370: %{name}-setup-fixes.patch

# Add a README file:
Patch1000: %{name}-add-readme.patch

# Replace the index page with one that doesn't include links to the user portal
# or webadmin:
Patch1010: %{name}-replace-index-page.patch

# The the service configuration and scripts:
Patch1020: %{name}-add-systemd-service.patch

# Build time requirements:
BuildRequires: apache-commons-beanutils
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-collections
BuildRequires: apache-commons-configuration
BuildRequires: apache-commons-jxpath
BuildRequires: apache-commons-lang
BuildRequires: apache-commons-logging
BuildRequires: apache-mina
BuildRequires: apache-sshd
BuildRequires: bea-stax-api
BuildRequires: dos2unix
BuildRequires: hibernate-jpa-2.0-api
BuildRequires: hibernate-validator
BuildRequires: jackson
BuildRequires: jakarta-commons-httpclient
BuildRequires: java-devel
BuildRequires: javamail
BuildRequires: javassist
BuildRequires: jboss-annotations-1.1-api
BuildRequires: jboss-ejb-3.1-api
BuildRequires: jboss-logging
BuildRequires: jboss-interceptors-1.1-api
BuildRequires: jboss-servlet-3.0-api
BuildRequires: jpackage-utils
BuildRequires: jsch
BuildRequires: log4j
BuildRequires: maven
BuildRequires: maven-antrun-plugin
BuildRequires: maven-assembly-plugin
BuildRequires: maven-checkstyle-plugin
BuildRequires: maven-clean-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-dependency-plugin
BuildRequires: maven-ear-plugin
BuildRequires: maven-eclipse-plugin
BuildRequires: maven-ejb-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-jaxb2-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-exec
BuildRequires: maven-resources-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-war-plugin
BuildRequires: postgresql-jdbc
BuildRequires: quartz
BuildRequires: resteasy
BuildRequires: springframework-instrument
BuildRequires: springframework-jdbc
BuildRequires: spring-ldap
BuildRequires: xmlrpc3-client

# Run time requirements (most of these requirements should be moved to the
# subpackages):
Requires: bea-stax-api
Requires: geronimo-validation
Requires: hibernate-jpa-2.0-api
Requires: hibernate-validator
Requires: jakarta-commons-httpclient
Requires: java
Requires: jboss-interceptors-1.1-api
Requires: jboss-logging
Requires: jpackage-utils
Requires: log4j
Requires: postgresql-jdbc
Requires: vdsm-bootstrap

# For local database:
Requires: postgresql-server
Requires: postgresql-contrib

# Require JBoss AS 7:
Requires: jboss-as >= 7.1.0-3

# Require the subpackages:
Requires: %{name}-config = %{version}-%{release}
Requires: %{name}-backend = %{version}-%{release}
Requires: %{name}-dbscripts = %{version}-%{release}
Requires: %{name}-iso-uploader = %{version}-%{release}
Requires: %{name}-log-collector = %{version}-%{release}
Requires: %{name}-notification-service = %{version}-%{release}
Requires: %{name}-restapi = %{version}-%{release}
Requires: %{name}-setup = %{version}-%{release}
Requires: %{name}-tools-common = %{version}-%{release}


%description
oVirt Engine is a feature-rich server virtualization management
system that provides advanced capabilities for managing the Open
virtualization infrastructure for Servers and Desktops.


%package config
Summary: Configuration tool for  Open Virtualization Manager
Group: Applications/System
Requires: %{name}-tools-common = %{version}-%{release}

%description config
The configuration tool for Open Virtualization Manager.


%package backend
Summary: Engine core of Open Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: antlr-tool
Requires: aopalliance
Requires: apache-commons-beanutils
Requires: apache-commons-codec
Requires: apache-commons-collections
Requires: apache-commons-lang
Requires: apache-mina
Requires: apache-sshd
Requires: bea-stax-api
Requires: dom4j
Requires: geronimo-validation
Requires: jackson
Requires: jakarta-commons-httpclient
Requires: java
Requires: javassist
Requires: jboss-interceptors-1.1-api
Requires: jsch
Requires: objectweb-asm
Requires: openssh
Requires: openssl
Requires: picketbox
Requires: quartz
Requires: slf4j
Requires: springframework
Requires: springframework-aop
Requires: springframework-beans
Requires: springframework-context
Requires: springframework-instrument
Requires: springframework-jdbc
Requires: springframework-tx
Requires: spring-ldap
Requires: ws-commons-util
Requires: xmlrpc3-client
Requires: xmlrpc3-common

%description backend
The backend engine of Open Virtualization Manager.


%package dbscripts
Summary: Database scripts for Open Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description dbscripts
Database scripts for Open Virtualization Manager.


%package iso-uploader
Summary: ISO Uploader tool for Open Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: python-lxml

%description iso-uploader
ISO Uploader tool for Open Virtualization Manager.


%package javadoc
Summary: Javadocs for %{name}
Group: Development/Libraries
Requires: jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.


%package log-collector
Summary: Log Collector tool for Open Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: python-lxml
Requires: sos

%description log-collector
Log Collector tool for Open Virtualization Manager.


%package notification-service
Summary: Notification service for Open Virtualization Manager Tools
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: %{name}-tools-common = %{version}-%{release}
Requires: javamail

%description notification-service
The notification service used by Open Virtualization Manager.


%package restapi
Summary: Open API for Red Hat Enterprise Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: aopalliance
Requires: apache-commons-codec
Requires: jakarta-commons-httpclient
Requires: httpcomponents-client
Requires: httpcomponents-core
Requires: jackson
Requires: javassist
Requires: glassfish-jaxb
Requires: glassfish-jaxb-api
Requires: jboss-logging
Requires: jcip-annotations
Requires: jettison
Requires: resteasy
Requires: scannotation
Requires: snakeyaml
Requires: bea-stax-api
Requires: istack-commons

%description restapi
The Open API for Red Hat Enterprise Virtualization Manager.


%package setup
Summary: Setup and upgrade scripts for Open Virtualization Manager
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: %{name}-config = %{version}-%{release}
Requires: %{name}-dbscripts = %{version}-%{release}
Requires: lsof
Requires: nfs-utils
Requires: cracklib-python

%description setup
Setup and upgrade scripts for Open Virtualization Manager.


%package tools-common
Summary: Common libraries for  Open Virtualization Manager Tools
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: apache-commons-codec
Requires: apache-commons-collections
Requires: apache-commons-configuration
Requires: apache-commons-jxpath
Requires: apache-commons-lang
Requires: apache-commons-logging
Requires: log4j

%description tools-common
The common libraries used by Open Virtualization Manager Tools.


%prep

# Unpack and patch the sources:
%setup -q -c -n %{name}-%{upstream_version}_%{upstream_release}

# Apply the patches:
%patch1 -p1
%patch0 -p1
%patch10 -p1
%patch20 -p1
%patch30 -p1
%patch40 -p1
%patch50 -p1
%patch60 -p1
%patch70 -p1
%patch80 -p1
%patch100 -p1
%patch110 -p1
%patch120 -p1
%patch130 -p1
%patch140 -p1
%patch150 -p1
%patch160 -p1
%patch170 -p1
%patch180 -p1
%patch190 -p1
%patch200 -p1
%patch210 -p1
%patch220 -p1
%patch240 -p1
%patch250 -p1
%patch260 -p1
%patch270 -p1
%patch310 -p1
%patch340 -p1
%patch350 -p1
%patch360 -p1
%patch370 -p1
%patch1000 -p1
%patch1010 -p1
%patch1020 -p1

# Remove some obsolete files:
rm -rf backend/manager/conf/ca/Setup.txt

# Remove extra modules that are not needed starting with JBoss AS 7.1:
rm -rf deployment/modules/org/jboss/as/naming
rm -rf deployment/modules/sun/jdk

# Fix the end of line of the database scripts:
find backend/manager/dbscripts -type f -name '*.sh' -exec dos2unix {} \;

# Remove the shebang (first line) from python generated files:
sed -i 1d \
backend/manager/tools/engine-logcollector/src/rhev/tests.py \
backend/manager/tools/engine-logcollector/src/rhev/schemas/jbossds.py \
backend/manager/tools/engine-logcollector/src/rhev/schemas/api.py \
backend/manager/tools/engine-iso-uploader/src/schemas/jbossds.py \
backend/manager/tools/engine-iso-uploader/src/schemas/api.py \
backend/manager/tools/engine-tools-common-lib/src/rhev/schemas/jbossds.py \
backend/manager/tools/engine-tools-common-lib/src/rhev/schemas/api.py


%build

# Use the makefile to do build, but instructing it to use mvn-rpmbuild instead
# of regular mvn and to skip completely the tests, as we don't have the
# required dependencies:
make \
  MVN="mvn-rpmbuild" \
  PREFIX="%{buildroot}" \
  BUILD_FLAGS="-Dmaven.test.skip=true -Dproject.build.sourceEncoding=ISO-8859-1 javadoc:aggregate" \
  build_mvn


%install

# Use the makefile to do the normal installation, after that we will need to
# replace jar files with links to their actual locations:
make \
  PREFIX="%{buildroot}" \
  install

# XXX: Need to review this, but right now they have to be removed to avoid
# rpmbuild complaints:
rm %{buildroot}/usr/share/java/engine-tools-common-3.0.0-0001.jar
rm %{buildroot}/usr/share/java/engine-tools-common.jar


# Create the directories required for jar and POM files:
install -d -m 755 %{buildroot}%{engine_jar_dir}
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}

# Jar and POM files:
while read module_path artifact_id subpackage_name
do
  pom_file="${module_path}/pom.xml"
  jar_file="${module_path}/target/${artifact_id}-%{upstream_version}-%{upstream_release}.jar"
  install -p -m 644 ${pom_file} %{buildroot}%{_mavenpomdir}/JPP.%{name}-${artifact_id}.pom
  if [ -f "${jar_file}" ]
  then
    install -p -m 644 ${jar_file} %{buildroot}%{engine_jar_dir}/${artifact_id}.jar
    %add_maven_depmap JPP.%{name}-${artifact_id}.pom %{name}/${artifact_id}.jar
  else
    %add_maven_depmap JPP.%{name}-${artifact_id}.pom
  fi
done <<'.'
. parent
backend backend
backend/manager manager
backend/manager/modules manager-modules
backend/manager/modules/compat compat
backend/manager/modules/engineencryptutils engineencryptutils
backend/manager/modules/common common
backend/manager/modules/utils utils
backend/manager/modules/dal dal
backend/manager/modules/vdsbroker vdsbroker
backend/manager/modules/searchbackend searchbackend
backend/manager/modules/beans manager-beans
backend/manager/modules/beans/scheduler scheduler
backend/manager/modules/beans/vdsbroker vdsbrokerbean
backend/manager/modules/bll bll
backend/manager/modules/restapi restapi-parent
backend/manager/modules/restapi/interface restapi-interface
backend/manager/modules/restapi/interface/definition restapi-definition
backend/manager/modules/restapi/interface/common/jaxrs interface-common-jaxrs
backend/manager/modules/restapi/types restapi-types
backend/manager/modules/restapi/jaxrs restapi-jaxrs
backend/manager/tools manager-tools
backend/manager/tools/engine-tools-common engine-tools-common
backend/manager/tools/engine-config engine-config
backend/manager/tools/engine-notifier engine-notifier
backend/manager/tools/engine-notifier/engine-notifier-service engine-notifier-service
backend/manager/tools/engine-notifier/engine-notifier-resources engine-notifier-resources
.

# Remove all the jar files, as they have to be replaced with links pointing to
# the actual locations:
find %{buildroot}%{engine_deployments_dir} -depth -name '*.jar' -exec rm -rf {} \;

# Remove manifests files as the dependencies there confuse the class loader:
find %{buildroot}%{engine_deployments_dir} -name MANIFEST.MF -delete

# Replace jar files in the ear with links to their actuals locations, first for
# jar files from this package, as for these can't use build-classpath:
while read jar_name ear_path
do
  ln -s %{engine_jar_dir}/${jar_name}.jar %{buildroot}%{engine_ear_dir}/${ear_path}.jar
done <<'.'
bll engine-bll
scheduler engine-scheduler
vdsbrokerbean engine-vdsbroker
common lib/engine-common
compat lib/engine-compat
dal lib/engine-dal
engineencryptutils lib/engine-encryptutils
engine-tools-common lib/engine-tools-common
utils lib/engine-utils
vdsbroker lib/vdsbroker
searchbackend lib/searchbackend
.

# Then for the system jar files (using build-classpath):
while read jar_name
do
  ln -s `build-classpath ${jar_name}` %{buildroot}%{engine_ear_dir}/lib
done <<'.'
antlr
aopalliance
apache-commons-beanutils
apache-commons-codec
apache-commons-collections
apache-commons-lang
apache-mina/mina-core
apache-sshd/sshd-core
bea-stax-api
dom4j
geronimo-validation
jackson/jackson-core-asl
jackson/jackson-mapper-asl
jakarta-commons-httpclient
jsch
objectweb-asm/asm-all
quartz
slf4j/api
slf4j/log4j12
springframework/spring-aop
springframework/spring-beans
springframework/spring-context
springframework/spring-core
springframework/spring-instrument
springframework/spring-jdbc
springframework/spring-tx
spring-ldap/spring-ldap-core
ws-commons-util
xmlrpc3-client
xmlrpc3-common
.

# Replace jar files in the RESTAPI web application with links to ther actual
# locations, first for jar files from this package, as for these can't use
# build-classpath:
while read jar_name
do
  ln -s %{engine_jar_dir}/${jar_name}.jar %{buildroot}%{restapi_war_dir}/WEB-INF/lib
done <<'.'
interface-common-jaxrs
restapi-definition
restapi-jaxrs
restapi-types
.

# Then for the system jar files (using build-classpath):
while read jar_name
do
  ln -s `build-classpath ${jar_name}` %{buildroot}%{restapi_war_dir}/WEB-INF/lib
done <<'.'
aopalliance
apache-commons-codec
jakarta-commons-httpclient
httpcomponents/httpclient
httpcomponents/httpcore
jackson/jackson-jaxrs
jackson/jackson-xc
javassist
jaxb-api
glassfish-jaxb/jaxb-impl
resteasy/jaxrs-api
jboss-logging
jcip-annotations
jettison
resteasy/resteasy-jackson-provider
resteasy/resteasy-jaxb-provider
resteasy/resteasy-jaxrs
resteasy/resteasy-jettison-provider
resteasy/resteasy-yaml-provider
scannotation
snakeyaml
bea-stax-api
istack-commons-runtime
.

# Javadoc files:
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -rp target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}


%files

# The main package owns most of the directories:
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/ovirt-isos
%dir %{_datadir}/%{name}/db-backups
%dir %{_datadir}/%{name}/scripts
%dir %{_localstatedir}/run/%{name}
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/log/%{name}
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/lock/%{name}
%{_datadir}/%{name}/scripts/vds_installer.py*
%{_datadir}/%{name}/scripts/ovirtlogrot.sh
%{_sysconfdir}/cron.daily/ovirt-cron
%config(noreplace) %{_sysconfdir}/tmpfiles.d/ovirt-engine.conf

# Engine configuration files:
%dir %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}/engine.conf
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}/ovirt-engine.xml
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}/ovirt-engine-logging.properties
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}/ovirt-engine-users.properties
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{_sysconfdir}/%{name}/web-conf.js

# Files needed by the systemd service:
%{engine_bin_dir}/ovirt-engine.sh
%{_unitdir}/ovirt-engine.service
%config(noreplace) %{_sysconfdir}/sysconfig/ovirt-engine

# The main package owns the dependencies map and directory containing the jar
# files (but not all its contents):
%{_mavendepmapfragdir}/%{name}
%dir %{engine_jar_dir}

# The parent POM:
%{_mavenpomdir}/JPP.%{name}-parent.pom

# Jar and POM files used by all the components:
%{engine_jar_dir}/common.jar
%{engine_jar_dir}/compat.jar
%{engine_jar_dir}/utils.jar
%{_mavenpomdir}/JPP.%{name}-common.pom
%{_mavenpomdir}/JPP.%{name}-compat.pom
%{_mavenpomdir}/JPP.%{name}-utils.pom

# Documentation:
%doc LICENSE


%files backend

# Jar files:
%{engine_jar_dir}/bll.jar
%{engine_jar_dir}/dal.jar
%{engine_jar_dir}/engine-config.jar
%{engine_jar_dir}/engineencryptutils.jar
%{engine_jar_dir}/scheduler.jar
%{engine_jar_dir}/searchbackend.jar
%{engine_jar_dir}/vdsbroker.jar
%{engine_jar_dir}/vdsbrokerbean.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-backend.pom
%{_mavenpomdir}/JPP.%{name}-manager.pom
%{_mavenpomdir}/JPP.%{name}-manager-beans.pom
%{_mavenpomdir}/JPP.%{name}-manager-modules.pom
%{_mavenpomdir}/JPP.%{name}-manager-tools.pom
%{_mavenpomdir}/JPP.%{name}-bll.pom
%{_mavenpomdir}/JPP.%{name}-dal.pom
%{_mavenpomdir}/JPP.%{name}-engine-config.pom
%{_mavenpomdir}/JPP.%{name}-engine-notifier-resources.pom
%{_mavenpomdir}/JPP.%{name}-engine-notifier-service.pom
%{_mavenpomdir}/JPP.%{name}-engineencryptutils.pom
%{_mavenpomdir}/JPP.%{name}-scheduler.pom
%{_mavenpomdir}/JPP.%{name}-searchbackend.pom
%{_mavenpomdir}/JPP.%{name}-vdsbroker.pom
%{_mavenpomdir}/JPP.%{name}-vdsbrokerbean.pom

# Directory for the engine modules that complement and override those provided
# by the application server:

# Directories for the deployments, contents and temporary files need to be
# owned by the engine because the application server needs to write to them:
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_deployments_dir}
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_content_dir}
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_temp_dir}

# This package owns the directory of the ear and some (not all) of its
# contents:
%dir %{engine_ear_dir}
%dir %{engine_ear_dir}/lib
%{engine_ear_dir}/META-INF
%{engine_ear_dir}/engine-bll.jar
%{engine_ear_dir}/engine-scheduler.jar
%{engine_ear_dir}/engine-vdsbroker.jar
%{engine_ear_dir}/lib/*.jar

# Root web application:
%{root_war_dir}

# Sysprep files:
%config(noreplace) %{_sysconfdir}/%{name}/sysprep

# PKI scripts:
%{engine_pki_dir}/*.sh
%{engine_pki_dir}/generate-ssh-keys

# PKI Directories are owned by the application server because it needs to
# create files inside:
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/certs
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/keys
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/private
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/requests

# PKI configuration files:
%config(noreplace) %{engine_pki_dir}/openssl.conf
%config(noreplace) %{engine_pki_dir}/cacert.template
%config(noreplace) %{engine_pki_dir}/cert.template

# The certificate database files are not created by the RPM, but by the scripts
# as needed:
%ghost %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/database.txt
%ghost %attr(-, %{engine_user}, %{engine_group}) %{engine_pki_dir}/serial.txt

# Modules:
%dir %{engine_modules_dir}
%{engine_modules_dir}/org/postgresql
%{engine_modules_dir}/com/sun/xml/bind
%{engine_modules_dir}/org/hibernate/validator


%files config

# Links to the main scripts:
%{_bindir}/engine-config
%{_bindir}/engine-manage-domains

# Scripts:
%{_datadir}/%{name}/engine-config
%{_datadir}/%{name}/engine-manage-domains
%{_datadir}/%{name}/kerberos

# Configuration files for the configuration tool:
%dir %{_sysconfdir}/%{name}/engine-config
%config(noreplace) %{_sysconfdir}/%{name}/engine-config/engine-config.conf
%config(noreplace) %{_sysconfdir}/%{name}/engine-config/engine-config.*properties
%config(noreplace) %{_sysconfdir}/%{name}/engine-config/log4j.xml

# Configuration files for the domain management tool:
%dir %{_sysconfdir}/%{name}/engine-manage-domains
%config(noreplace) %{_sysconfdir}/%{name}/engine-manage-domains/engine-manage-domains.conf
%config(noreplace) %{_sysconfdir}/%{name}/engine-manage-domains/log4j.xml


%files dbscripts
%{_datadir}/%{name}/dbscripts


%files iso-uploader

# Link to the main program:
%{_bindir}/engine-iso-uploader

# Python scripts:
%{_datadir}/%{name}/iso-uploader

# Configuration files:
%config(noreplace) %{_sysconfdir}/%{name}/isouploader.conf

# Manual pages:
%doc %{_mandir}/man8/engine-iso-uploader.8.gz


%files javadoc

%{_javadocdir}/%{name}


%files log-collector

# Main program:
%{_bindir}/engine-log-collector

# Python files:
%{_datadir}/%{name}/log-collector

# SOS plugins:
%{py_site_pkgs}/sos/plugins/engine.py*
%{py_site_pkgs}/sos/plugins/jboss.py*
%{py_site_pkgs}/sos/plugins/postgresql.py*

# Configuration files:
%config(noreplace) %{_sysconfdir}/%{name}/logcollector.conf

# Manual page pages:
%doc %{_mandir}/man8/engine-log-collector.8.gz

%doc LICENSE


%files notification-service

# Startup scripts:
%{_datadir}/%{name}/notifier
%{_sysconfdir}/init.d/engine-notifierd

# Log and state directories must be owned by ovirt because the notifier service
# runs with that user and needs to write them:
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/log/%{name}/notifier
%dir %attr(-, %{engine_user}, %{engine_group}) %{_localstatedir}/run/%{name}/notifier

# Configuration files:
%dir %{_sysconfdir}/%{name}/notifier
%config(noreplace) %{_sysconfdir}/%{name}/notifier/notifier.conf
%config(noreplace) %{_sysconfdir}/%{name}/notifier/log4j.xml

# Jar files:
%{engine_jar_dir}/engine-notifier-service.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-engine-notifier.pom


%files restapi

# Jar files:
%{engine_jar_dir}/interface-common-jaxrs.jar
%{engine_jar_dir}/restapi-definition.jar
%{engine_jar_dir}/restapi-jaxrs.jar
%{engine_jar_dir}/restapi-types.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-interface-common-jaxrs.pom
%{_mavenpomdir}/JPP.%{name}-restapi-definition.pom
%{_mavenpomdir}/JPP.%{name}-restapi-interface.pom
%{_mavenpomdir}/JPP.%{name}-restapi-jaxrs.pom
%{_mavenpomdir}/JPP.%{name}-restapi-parent.pom
%{_mavenpomdir}/JPP.%{name}-restapi-types.pom

# Everything inside of the web application is owned by this subpackage:
%{restapi_war_dir}


%files setup

# Links to the main programs:
%{_bindir}/engine-setup
%{_bindir}/engine-cleanup

# Python scripts:
%{_datadir}/%{name}/scripts/basedefs.py*
%{_datadir}/%{name}/scripts/engine_validators.py*
%{_datadir}/%{name}/scripts/common_utils.py*
%{_datadir}/%{name}/scripts/output_messages.py*
%{_datadir}/%{name}/scripts/nfsutils.py*
%{_datadir}/%{name}/scripts/engine-setup.py*
%{_datadir}/%{name}/scripts/engine-cleanup.py*

# Resources used during the setup:
%dir %{_datadir}/%{name}/resources
%{_datadir}/%{name}/conf

# The main web application:
# XXX: I think this should be directly installed inside the .ear or in the
# deployments directory instead of having the setup tool copy it.
%{_datadir}/%{name}/resources/jboss


%files tools-common

# Jar files:
%{engine_jar_dir}/engine-tools-common.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-engine-tools-common.pom


# Create the ovirt group and group for all the subpackages that contain
# files owned by them:
%pre
%create_engine_user

%pre backend
%create_engine_user

%pre notification-service
%create_engine_user


%post notification-service

# Register the service:
/sbin/chkconfig --add engine-notifierd


%preun notification-service

# If the last version of the package is going to be removed then stop and
# disable the service:
if [ $1 = 0 ]
then
  /sbin/service engine-notifierd stop > /dev/null 2>&1
  /sbin/chkconfig --del engine-notifierd
fi


%changelog
* Tue Apr 24 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-12
- Fixes needed to work with the jboss-as package
- Added systemd service files

* Thu Apr 12 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-11
- Moved the upstream release number to the version tag

* Thu Apr 12 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-10
- Remove license header from the spec
- Use global instead of define
- Don't use include for subpackages
- Don't use dangerous commands in scripts

* Sun Apr 01 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-9
- Use the name macro to build the url
- Move sysprep files to the /etc directory
- Added javadoc subpackage
- Move the upstream release number to the release tag
- Use an standard software group

* Wed Mar 28 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-8
- Make main package require the subpackages

* Wed Mar 28 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-7
- Make setup subpackage depend on the dbscripts subpackage

* Mon Mar 26 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-6
- Cleanup of the spec file

* Mon Mar 26 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-5
- Replaced geronimo and tomcat API packages with equivalent jboss packages
- Removed c3p0 and snakeyml dependencies

* Thu Mar 15 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-4
- Adjusted to build in Fedora from source

* Wed Jan 04 2012 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-3
- Adjust code for Jboss AS 7.1

* Sun Dec 11 2011 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-2
- Moved all hard coded paths to macros

* Wed Oct 26 2011 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-1
- Initial build
- Cloned from RHEVM spec file
